summaryrefslogtreecommitdiff
path: root/src/newgrf_town.cpp
diff options
context:
space:
mode:
authorsmatz <smatz@openttd.org>2009-06-23 09:52:26 +0000
committersmatz <smatz@openttd.org>2009-06-23 09:52:26 +0000
commita50ba1b8c1afc164cf14750d9c1a89dfec9dd25a (patch)
treeb5ac362a349f29b8ddc25f933433adb792827ad6 /src/newgrf_town.cpp
parent5ef0745254f8fe94f608ac5e1f31c8bb47f1a336 (diff)
downloadopenttd-a50ba1b8c1afc164cf14750d9c1a89dfec9dd25a.tar.xz
(svn r16632) -Codechange: rename Town::flags12 to Town::flags
Diffstat (limited to 'src/newgrf_town.cpp')
-rw-r--r--src/newgrf_town.cpp2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/newgrf_town.cpp b/src/newgrf_town.cpp
index 084bf640c..279c761e5 100644
--- a/src/newgrf_town.cpp
+++ b/src/newgrf_town.cpp
@@ -30,7 +30,7 @@ uint32 TownGetVariable(byte variable, byte parameter, bool *available, const Tow
case 0x82: return ClampToU16(t->population);
case 0x83: return GB(ClampToU16(t->population), 8, 8);
case 0x8A: return t->grow_counter;
- case 0x92: return t->flags12; // In original game, 0x92 and 0x93 are really one word. Since flags12 is a byte, this is to adjust
+ case 0x92: return t->flags; // In original game, 0x92 and 0x93 are really one word. Since flags is a byte, this is to adjust
case 0x93: return 0;
case 0x94: return ClampToU16(t->squared_town_zone_radius[0]);
case 0x95: return GB(ClampToU16(t->squared_town_zone_radius[0]), 8, 8);